==> givemefive_0.2.20080916-1.tar.gz: givemefive-0.2.20080916/src/Control.h <==
#ifndef CONTROL_H
#define CONTROL_H

/*
  This file is part of "GiveMeFive" - A simple "five in a row" game.
  Copyright (C) 2007  Tim Teulings

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include <Lum/Object.h>

#include "GameArea.h"

class Control : public Lum::Control
{
private:
  GameAreaRef model;
  size_t            cellSize;
  Lum::OS::ColorRef backgroundColor;
  Lum::OS::ColorRef lineColor;
  Lum::OS::ColorRef player1Color;
  Lum::OS::ColorRef player2Color;
  Lum::OS::ColorRef markColor;

public:
  Control();

  void CalcSize();

  bool SetModel(Lum::Base::Model* model);

  void Layout();
  void Draw(int x, int y, size_t w, size_t h);

  bool HandleMouseEvent(const Lum::OS::MouseEvent& event);
  bool HandleKeyEvent(const Lum::OS::KeyEvent& event);

  void Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& msg);

};

#endif

==> givemefive_0.2.20101220-1.tar.gz: givemefive-0.2.20101220/src/Control.h <==
#ifndef CONTROL_H
#define CONTROL_H

/*
  This file is part of "GiveMeFive" - A simple "five in a row" game.
  Copyright (C) 2007  Tim Teulings

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include <Lum/Object.h>

#include "GameArea.h"

class Control : public Lum::Control
{
private:
  GameAreaRef model;
  size_t            cellSize;
  Lum::OS::ColorRef backgroundColor;
  Lum::OS::ColorRef lineColor;
  Lum::OS::ColorRef player1Color;
  Lum::OS::ColorRef player2Color;
  Lum::OS::ColorRef markColor;

public:
  Control();

  void CalcSize();

  bool SetModel(Lum::Base::Model* model);

  void Layout();
  void Draw(Lum::OS::DrawInfo* draw,
            int x, int y, size_t w, size_t h);

  bool HandleMouseEvent(const Lum::OS::MouseEvent& event);
  bool HandleKeyEvent(const Lum::OS::KeyEvent& event);

  void Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& msg);

};

#endif
